==> audit_2.4.orig.tar.gz: audit-2.4/auparse/ipoptnametab.h <==
/* ipoptnametab.h --
 * Copyright 2013 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors:
 *      Steve Grubb <sgrubb@redhat.com>
 * Location: include/uapi/linux/in.h
 *           include/uapi/linux/netfilter_ipv4/ip_tables.h
 */


_S(1, "IP_TOS")
_S(2, "IP_TTL")
_S(3, "IP_HDRINCL")
_S(4, "IP_OPTIONS")
_S(5, "IP_ROUTER_ALERT")
_S(6, "IP_RECVOPTS")
_S(7, "IP_RETOPTS")
_S(8, "IP_PKTINFO")
_S(9, "IP_PKTOPTIONS")
_S(10, "IP_MTU_DISCOVER")
_S(11, "IP_RECVERR")
_S(12, "IP_RECVTTL")
_S(14, "IP_MTU")
_S(15, "IP_FREEBIND")
_S(16, "IP_IPSEC_POLICY")
_S(17, "IP_XFRM_POLICY")
_S(18, "IP_PASSSEC")
_S(19, "IP_TRANSPARENT")
_S(20, "IP_ORIGDSTADDR")
_S(21, "IP_MINTTL")
_S(22, "IP_NODEFRAG")
_S(32, "IP_MULTICAST_IF")
_S(33, "IP_MULTICAST_TTL")
_S(34, "IP_MULTICAST_LOOP")
_S(35, "IP_ADD_MEMBERSHIP")
_S(36, "IP_DROP_MEMBERSHIP")
_S(37, "IP_UNBLOCK_SOURCE")
_S(38, "IP_BLOCK_SOURCE")
_S(39, "IP_ADD_SOURCE_MEMBERSHIP")
_S(40, "IP_DROP_SOURCE_MEMBERSHIP")
_S(41, "IP_MSFILTER")
_S(49, "IP_MULTICAST_ALL")
_S(50, "IP_UNICAST_IF")
_S(64, "IPT_SO_SET_REPLACE")
_S(65, "IPT_SO_SET_ADD_COUNTERS")
_S(66, "IPT_SO_GET_REVISION_TARGET")

==> audit_2.8.2.orig.tar.gz: audit-2.8.2/auparse/ipoptnametab.h <==
/* ipoptnametab.h --
 * Copyright 2013,2015 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors:
 *      Steve Grubb <sgrubb@redhat.com>
 * Location: include/uapi/linux/in.h
 *           include/uapi/linux/netfilter_ipv4/ip_tables.h
 */


_S(1, "IP_TOS")
_S(2, "IP_TTL")
_S(3, "IP_HDRINCL")
_S(4, "IP_OPTIONS")
_S(5, "IP_ROUTER_ALERT")
_S(6, "IP_RECVOPTS")
_S(7, "IP_RETOPTS")
_S(8, "IP_PKTINFO")
_S(9, "IP_PKTOPTIONS")
_S(10, "IP_MTU_DISCOVER")
_S(11, "IP_RECVERR")
_S(12, "IP_RECVTTL")
_S(14, "IP_MTU")
_S(15, "IP_FREEBIND")
_S(16, "IP_IPSEC_POLICY")
_S(17, "IP_XFRM_POLICY")
_S(18, "IP_PASSSEC")
_S(19, "IP_TRANSPARENT")
_S(20, "IP_ORIGDSTADDR")
_S(21, "IP_MINTTL")
_S(22, "IP_NODEFRAG")
_S(23, "IP_CHECKSUM")
_S(32, "IP_MULTICAST_IF")
_S(33, "IP_MULTICAST_TTL")
_S(34, "IP_MULTICAST_LOOP")
_S(35, "IP_ADD_MEMBERSHIP")
_S(36, "IP_DROP_MEMBERSHIP")
_S(37, "IP_UNBLOCK_SOURCE")
_S(38, "IP_BLOCK_SOURCE")
_S(39, "IP_ADD_SOURCE_MEMBERSHIP")
_S(40, "IP_DROP_SOURCE_MEMBERSHIP")
_S(41, "IP_MSFILTER")
_S(42, "MCAST_JOIN_GROUP")
_S(43, "MCAST_BLOCK_SOURCE")
_S(44, "MCAST_UNBLOCK_SOURCE")
_S(45, "MCAST_LEAVE_GROUP")
_S(46, "MCAST_JOIN_SOURCE_GROUP")
_S(47, "MCAST_LEAVE_SOURCE_GROUP")
_S(48, "MCAST_MSFILTER")
_S(49, "IP_MULTICAST_ALL")
_S(50, "IP_UNICAST_IF")
_S(64, "IPT_SO_SET_REPLACE")
_S(65, "IPT_SO_SET_ADD_COUNTERS")
_S(66, "IPT_SO_GET_REVISION_TARGET")
